@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2025 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -42,7 +42,7 @@ typedef HANDLE MonitorEntry;
 #elif defined(HAVE_SYS_POLL_H)
 #define ASYNC_CAN_MONITOR_IO
 
-#include <sys/poll.h>
+#include <poll.h>
 typedef struct pollfd MonitorEntry;
 
 #elif defined(GOT_SELECT)
@@ -159,7 +159,7 @@ struct AsyncIoDataStruct {
 void
 asyncDeallocateIoData (AsyncIoData *iod) {
   if (iod) {
-    if (iod->functionQueue) deallocateQueue(iod->functionQueue);
+    if (iod->functionQueue) destroyQueue(iod->functionQueue);
     free(iod);
   }
 }
@@ -559,7 +559,7 @@ static void
 deallocateFunctionEntry (void *item, void *data) {
   FunctionEntry *function = item;
 
-  if (function->operations) deallocateQueue(function->operations);
+  if (function->operations) destroyQueue(function->operations);
   if (function->methods->endFunction) function->methods->endFunction(function);
   free(function);
 }
@@ -875,7 +875,7 @@ getFunctionElement (FileDescriptor fileDescriptor, const FunctionMethods *method
             if (element) return element;
           }
 
-          deallocateQueue(function->operations);
+          destroyQueue(function->operations);
         }
 
         free(function);
