@@ -73,6 +73,7 @@
 #include "prefs.h"
 #include "api_control.h"
 #include "options.h"
+#include "program.h"
 #include "core.h"
 
 #ifdef ENABLE_SPEECH_SUPPORT
@@ -366,6 +367,11 @@ updateSessionAttributes (void) {
       value += 1;
     }
   }
+
+  // Notify routing system that screen was updated
+  if (isRouting()) {
+    onCursorPositionChanged();
+  }
 }
 
 void
@@ -416,8 +422,7 @@ fillStatusSeparator (wchar_t *text, unsigned char *dots) {
     }
 
     {
-      unsigned int row;
-      for (row=0; row<brl.textRows; row+=1) {
+      for (unsigned int row=0; row<brl.textRows; row+=1) {
         *text = textSeparator;
         text += brl.textColumns;
 
@@ -429,20 +434,23 @@ fillStatusSeparator (wchar_t *text, unsigned char *dots) {
 }
 
 int
-writeBrailleCharacters (const char *mode, const wchar_t *characters, size_t length) {
+writeBrailleCharacters (const char *label, const wchar_t *characters, size_t length) {
   wchar_t textBuffer[brl.textColumns * brl.textRows];
 
-  fillTextRegion(textBuffer, brl.buffer,
-                 textStart, textCount, brl.textColumns, brl.textRows,
-                 characters, length);
+  fillTextRegion(
+    textBuffer, brl.buffer, textStart, textCount,
+    brl.textColumns, brl.textRows, characters, length
+  );
 
   {
-    size_t modeLength = mode? countUtf8Characters(mode): 0;
-    wchar_t modeCharacters[modeLength + 1];
-    makeWcharsFromUtf8(mode, modeCharacters, ARRAY_COUNT(modeCharacters));
-    fillTextRegion(textBuffer, brl.buffer,
-                   statusStart, statusCount, brl.textColumns, brl.textRows,
-                   modeCharacters, modeLength);
+    size_t labelLength = label? countUtf8Characters(label): 0;
+    wchar_t labelCharacters[labelLength + 1];
+    makeWcharsFromUtf8(label, labelCharacters, ARRAY_COUNT(labelCharacters));
+
+    fillTextRegion(
+      textBuffer, brl.buffer, statusStart, statusCount,
+      brl.textColumns, brl.textRows, labelCharacters, labelLength
+    );
   }
 
   fillStatusSeparator(textBuffer, brl.buffer);
@@ -1035,7 +1043,7 @@ sayScreenCharacters (const ScreenCharacter *characters, size_t count, SayOptions
 
       while (character < end) {
         *text++ = character->text;
-        *attributes++ = character->attributes;
+        *attributes++ = getScreenColorAttributes(&character->color);
         character += 1;
       }
 
@@ -1072,7 +1080,7 @@ speakCharacters (const ScreenCharacter *characters, size_t count, int spell, int
     }
   } else if (count == 1) {
     wchar_t character = characters[0].text;
-    unsigned char attributes = characters[0].attributes;
+    unsigned char attributes = getScreenColorAttributes(&characters[0].color);
     const char *prefix = NULL;
 
     if (iswupper(character)) {
@@ -1103,7 +1111,7 @@ speakCharacters (const ScreenCharacter *characters, size_t count, int spell, int
       textBuffer[length++] = character;
 
       unsigned char attributesBuffer[length];
-      memset(attributesBuffer, SCR_COLOUR_DEFAULT, length);
+      memset(attributesBuffer, VGA_COLOR_DEFAULT, length);
       attributesBuffer[length-1] = attributes;
 
       sayWideCharacters(&spk, textBuffer, attributesBuffer, length, sayOptions);
@@ -1123,14 +1131,15 @@ speakCharacters (const ScreenCharacter *characters, size_t count, int spell, int
 
     while (character < end) {
       *text++ = character->text;
-      *attributes++ = character->attributes;
+      *attributes++ = getScreenColorAttributes(&character->color);
 
       *text++ = WC_C(' ');
-      *attributes++ = SCR_COLOUR_DEFAULT;
+      *attributes++ = VGA_COLOR_DEFAULT;
 
       character += 1;
     }
 
+    sayOptions |= SAY_OPT_ALL_PUNCTUATION;
     sayWideCharacters(&spk, textBuffer, attributesBuffer, length-1, sayOptions);
   } else {
     sayScreenCharacters(characters, count, sayOptions);
@@ -1223,11 +1232,11 @@ isSameText (
 }
 
 int
-isSameAttributes (
+isSameScreenColor (
   const ScreenCharacter *character1,
   const ScreenCharacter *character2
 ) {
-  return character1->attributes == character2->attributes;
+  return sameScreenColors(&character1->color, &character2->color);
 }
 
 int
@@ -1235,7 +1244,7 @@ isSameCharacter (
   const ScreenCharacter *character1,
   const ScreenCharacter *character2
 ) {
-  return isSameText(character1, character2) && isSameAttributes(character1, character2);
+  return isSameText(character1, character2) && isSameScreenColor(character1, character2);
 }
 
 int
