@@ -23,7 +23,6 @@
 #include <strings.h>
 #include <ctype.h>
 
-#include "program.h"
 #include "cmdline.h"
 #include "options.h"
 #include "log.h"
@@ -37,7 +36,7 @@ static char *opt_boxHeight;
 char *opt_screenDriver;
 char *opt_driversDirectory;
 
-BEGIN_OPTION_TABLE(programOptions)
+BEGIN_COMMAND_LINE_OPTIONS(programOptions)
   { .word = "screen-driver",
     .letter = 'x',
     .argument = "driver",
@@ -82,7 +81,27 @@ BEGIN_OPTION_TABLE(programOptions)
     .internal.adjust = toAbsoluteInstallPath,
     .description = "Path to directory for loading drivers."
   },
-END_OPTION_TABLE(programOptions)
+END_COMMAND_LINE_OPTIONS(programOptions)
+
+BEGIN_COMMAND_LINE_PARAMETERS(programParameters)
+END_COMMAND_LINE_PARAMETERS(programParameters)
+
+BEGIN_COMMAND_LINE_NOTES(programNotes)
+END_COMMAND_LINE_NOTES
+
+BEGIN_COMMAND_LINE_DESCRIPTOR(programDescriptor)
+  .name = "scrtest",
+  .purpose = strtext("Test a screen driver."),
+
+  .options = &programOptions,
+  .parameters = &programParameters,
+  .notes = COMMAND_LINE_NOTES(programNotes),
+
+  .extraParameters = {
+    .name = "name=value",
+    .description = "parameters for the specified screen driver",
+  },
+END_COMMAND_LINE_DESCRIPTOR
 
 static int
 setRegion (
@@ -126,23 +145,11 @@ setRegion (
 
 int
 main (int argc, char *argv[]) {
+  PROCESS_COMMAND_LINE(programDescriptor, argc, argv);
+
   ProgramExitStatus exitStatus;
   void *driverObject;
 
-  {
-    const CommandLineDescriptor descriptor = {
-      .options = &programOptions,
-      .applicationName = "scrtest",
-
-      .usage = {
-        .purpose = strtext("Test a screen driver."),
-        .parameters = "[parameter=value ...]",
-      }
-    };
-
-    PROCESS_OPTIONS(descriptor, argc, argv);
-  }
-
   if ((screen = loadScreenDriver(opt_screenDriver, &driverObject, opt_driversDirectory))) {
     const char *const *parameterNames = getScreenParameters(screen);
     char **parameterSettings;
@@ -170,7 +177,7 @@ main (int argc, char *argv[]) {
     while (argc) {
       char *assignment = *argv++;
       int ok = 0;
-      char *delimiter = strchr(assignment, '=');
+      char *delimiter = strchr(assignment, PARAMETER_ASSIGNMENT_CHARACTER);
       if (!delimiter) {
         logMessage(LOG_ERR, "missing screen parameter value: %s", assignment);
       } else if (delimiter == assignment) {
@@ -247,6 +254,7 @@ main (int argc, char *argv[]) {
     logMessage(LOG_ERR, "can't load screen driver.");
     exitStatus = PROG_EXIT_FATAL;
   }
+
   return exitStatus;
 }
 
@@ -255,3 +263,10 @@ main (int argc, char *argv[]) {
 void
 scheduleUpdateIn (const char *reason, int delay) {
 }
+
+#include "embed.h"
+
+int
+brlttyInterrupt (WaitResult waitResult) {
+  return 1;
+}
