@@ -52,17 +52,17 @@ overlayAttributesUnderline (unsigned char *cell, unsigned char attributes) {
   unsigned char dots;
 
   switch (attributes) {
-    case SCR_COLOUR_FG_DARK_GREY | SCR_COLOUR_BG_BLACK:
-    case SCR_COLOUR_FG_LIGHT_GREY | SCR_COLOUR_BG_BLACK:
-    case SCR_COLOUR_FG_LIGHT_GREY | SCR_COLOUR_BG_BLUE:
-    case SCR_COLOUR_FG_BLACK | SCR_COLOUR_BG_CYAN:
+    case VGA_COLOR_FG_DARK_GRAY | VGA_COLOR_BG_BLACK:
+    case VGA_COLOR_FG_LIGHT_GRAY | VGA_COLOR_BG_BLACK:
+    case VGA_COLOR_FG_LIGHT_GRAY | VGA_COLOR_BG_BLUE:
+    case VGA_COLOR_FG_BLACK | VGA_COLOR_BG_CYAN:
       return;
 
-    case SCR_COLOUR_FG_BLACK | SCR_COLOUR_BG_LIGHT_GREY:
+    case VGA_COLOR_FG_BLACK | VGA_COLOR_BG_LIGHT_GRAY:
       dots = BRL_DOT_7 | BRL_DOT_8;
       break;
 
-    case SCR_COLOUR_FG_WHITE | SCR_COLOUR_BG_BLACK:
+    case VGA_COLOR_FG_WHITE | VGA_COLOR_BG_BLACK:
     default:
       dots = BRL_DOT_8;
       break;
@@ -151,7 +151,7 @@ translateScreenCharacter_text (
   }
 
   if (prefs.showAttributes) {
-    overlayAttributesUnderline(cell, character->attributes);
+    overlayAttributesUnderline(cell, getScreenColorAttributes(&character->color));
   }
 
   {
@@ -170,7 +170,11 @@ static void
 translateScreenCharacter_attributes (
   const ScreenCharacter *character, unsigned char *cell, wchar_t *text
 ) {
-  *text = UNICODE_BRAILLE_ROW | (*cell = convertAttributesToDots(attributesTable, character->attributes));
+  *text = UNICODE_BRAILLE_ROW | (
+    *cell = convertAttributesToDots(
+      attributesTable, getScreenColorAttributes(&character->color)
+    )
+  );
 }
 
 static void
@@ -358,7 +362,7 @@ contractScreenRow (BrailleRowDescriptor *brd, unsigned int screenRow, unsigned c
         attributes = 0;
       }
 
-      attributes |= inputCharacters[inputOffset].attributes;
+      attributes |= getScreenColorAttributes(&inputCharacters[inputOffset].color);
     }
 
     while (outputOffset < outputLength) {
@@ -1273,9 +1277,11 @@ doUpdate (void) {
           unsigned char cells[length];
           memset(cells, 0, length);
           renderStatusFields(fields, cells);
-          fillDotsRegion(textBuffer, brl.buffer,
-                         statusStart, statusCount, brl.textColumns, brl.textRows,
-                         cells, length);
+
+          fillDotsRegion(
+            textBuffer, brl.buffer, statusStart, statusCount,
+            brl.textColumns, brl.textRows, cells, length
+          );
         }
 
         fillStatusSeparator(textBuffer, brl.buffer);
